@@ -47,6 +47,7 @@ tests = return
         ("a")
         ([Left "a"])
 #endif
+    , Test $ runParserTest "empty input" (sepCap (fail "" :: Parser ())) "" []
     , Test $ streamEditTest "x to o"
         (string "x" :: Parser B.ByteString) (const "o")
         "x x x" "o o o"
@@ -56,6 +57,15 @@ tests = return
     , Test $ streamEditTest "ordering"
         (string "456" :: Parser B.ByteString) (const "ABC")
         "123456789" "123ABC789"
+    , Test $ streamEditTest "empty input" (match (fail "" :: Parser ())) (fst) "" ""
+    , Test $ breakCapTest "basic" (upperChar :: Parser Word8) "aAa" (Just ("a", c2w 'A', "a"))
+    , Test $ breakCapTest "first" (upperChar :: Parser Word8) "Aa" (Just ("", c2w 'A', "a"))
+    , Test $ breakCapTest "last" (upperChar :: Parser Word8) "aA" (Just ("a", c2w 'A', ""))
+    , Test $ breakCapTest "fail" (upperChar :: Parser Word8) "aaa" Nothing
+    , Test $ breakCapTest "match" (match (upperChar :: Parser Word8)) "aAa" (Just ("a", ("A",c2w 'A'), "a"))
+    , Test $ breakCapTest "zero-width" (lookAhead (upperChar :: Parser Word8)) "aAa" (Just ("a", c2w 'A', "Aa"))
+    , Test $ breakCapTest "empty input" (upperChar :: Parser Word8) "" Nothing
+    , Test $ breakCapTest "empty input zero-width" (return () :: Parser ()) "" (Just ("", (), ""))
     ]
   where
     runParserTest nam p input expected = TestInstance
@@ -66,7 +76,7 @@ tests = return
                         if (output == expected)
                             then return (Finished Pass)
                             else return (Finished $ Fail
-                                        $ show output ++ " ≠ " ++ show expected)
+                                        $ "got " <> show output <> " expected " <> show expected)
             , name = nam
             , tags = []
             , options = []
@@ -79,13 +89,26 @@ tests = return
                 if (output == expected)
                     then return (Finished Pass)
                     else return (Finished $ TestSuite.Fail
-                                $ show output ++ " ≠ " ++ show expected)
+                                $ "got " <> show output <> " expected " <> show expected)
             , name = "streamEdit " ++ nam
             , tags = []
             , options = []
             , setOption = \_ _ -> Left "no options supported"
             }
 
+    breakCapTest nam sep input expected = TestInstance
+            { run = do
+                let output = breakCap sep input
+                if (output == expected)
+                    then return (Finished Pass)
+                    else return (Finished $ TestSuite.Fail
+                                $ "got " <> show output <> " expected " <> show expected)
+            , name = "breakCap " ++ nam
+            , tags = []
+            , options = []
+            , setOption = \_ _ -> Left "no options supported"
+            }
+
     scinum :: Parser (Double, Integer)
     scinum = do
         -- This won't parse mantissas that contain a decimal point,
@@ -96,7 +119,6 @@ tests = return
         e <- decimal
         return (m, e)
 
-
     offsetA :: Parser Int
     offsetA = getOffset <* chunk "A"
 
